@@ -11,17 +11,20 @@
 #include "video/webcamcontrol.h"
 #include <QApplication>
 #include <QIcon>
+#include <KirigamiApp>
 
 #include "kamoso_version.h"
 #include <gst/gst.h>
 
 int main(int argc, char *argv[])
 {
-    QApplication app(argc, argv);
+    KirigamiApp::App app(argc, argv);
+    KirigamiApp kapp;
+
     KLocalizedString::setApplicationDomain("kamoso");
     {
         KAboutData about(QStringLiteral("kamoso"), i18n("Kamoso"), QStringLiteral(KAMOSO_VERSION_STRING), i18n("Utility for taking photos and videos using a webcam"),
-                         KAboutLicense::GPL, i18n("(C) 2008-2015 Alex Fiestas and Aleix Pol"));
+                         KAboutLicense::GPL, i18n("(C) 2008-2025 Alex Fiestas and Aleix Pol"));
 
         about.addAuthor( i18n("Aleix Pol Gonzalez"), i18n("Semaphore hacker"), QStringLiteral("aleixpol@kde.org"));
         about.addAuthor( i18n("Alex Fiestas"), i18n("Coffee drinker"), QStringLiteral("afiestas@kde.org"));
